16.9. cdist-type__apt_ppa(7) — cdist 6.9.8 documentation

# 16.9. cdist-type__apt_ppa(7)

## 16.9.1. NAME

cdist-type__apt_ppa - Manage ppa repositories

## 16.9.2. DESCRIPTION

This cdist type allows manage ubuntu ppa repositories.

## 16.9.3. REQUIRED PARAMETERS

state

  The state the ppa should be in, either 'present' or 'absent'. Defaults to 'present'

## 16.9.4. OPTIONAL PARAMETERS

None.

## 16.9.5. EXAMPLES

    # Enable a ppa repository
    __apt_ppa ppa:sans-intern/missing-bits
    # same as
    __apt_ppa ppa:sans-intern/missing-bits --state present

    # Disable a ppa repository
    __apt_ppa ppa:sans-intern/missing-bits --state absent

## 16.9.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.9.7. COPYING

Copyright (C) 2011-2014 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.